OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Ingebed bericht %s",
    "Important mail" : "Belangrijke mail",
    "Unread mail" : "Ongelezen mail",
    "Important" : "Belangrijk",
    "Work" : "Werk",
    "Personal" : "Persoonlijk",
    "To Do" : "Te doen",
    "Later" : "Later",
    "Mails" : "Mails",
    "Mail" : "E-mail",
    "💌 A mail app for Nextcloud" : "💌 Een e-mail app voor Nextcloud",
    "Drafts are saved in:" : "Concepten worden opgeslagen in:",
    "Sent messages are saved in:" : "Verzonden berichten worden opgeslagen in:",
    "Deleted messages are moved in:" : "Verwijderde berichten worden verplaatst naar:",
    "Auto" : "Automatisch",
    "Name" : "Naam",
    "Mail address" : "E-mailadres",
    "name@example.org" : "naam@voorbeeld.org",
    "Password" : "Wachtwoord",
    "Manual" : "Handmatig",
    "IMAP Settings" : "IMAP instellingen",
    "IMAP Host" : "IMAP host",
    "IMAP Security" : "IMAP beveiliging",
    "None" : "Geen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP poort",
    "IMAP User" : "IMAP gebruikersnaam",
    "IMAP Password" : "IMAP wachtwoord",
    "SMTP Settings" : "SMTP instellingen",
    "SMTP Host" : "SMTP host",
    "SMTP Security" : "SMTP beveiliging",
    "SMTP Port" : "SMTP poort",
    "SMTP User" : "SMTP gebruikersnaam",
    "SMTP Password" : "SMTP wachtwoord",
    "Connecting" : "Verbinden",
    "Sign in with Google" : "Inloggen met Google",
    "Save" : "Bewaren",
    "Connect" : "Verbinden",
    "Password required" : "Wachtwoord vereist",
    "Account settings" : "Accountinstellingen",
    "Signature" : "Handtekening",
    "A signature is added to the text of new messages and replies." : "Een handtekening wordt toegevoegd aan de tekst van nieuwe berichten en antwoorden.",
    "Writing mode" : "Schrijfmodus",
    "Preferred writing mode for new messages and replies." : "Gewenste schrijfmodus voor nieuwe berichten en antwoorden.",
    "Default folders" : "Standaardmappen",
    "Sieve filter rules" : "Sieve filterregels",
    "Trusted senders" : "Vertrouwde afzenders",
    "Mail server" : "Mailserver",
    "Sieve filter server" : "Sieve filterserver",
    "Update alias" : "Bijwerken alias",
    "Show update alias form" : "Toon formulier Bijwerken alias",
    "Delete alias" : "Verwijderen alias",
    "Change name" : "Naam veranderen",
    "Email address" : "E-mailadres",
    "Add alias" : "Voeg bijnaam toe",
    "Create alias" : "Aanmaken alias",
    "Cancel" : "Annuleren",
    "Add mail account" : "Voeg e-mailaccount toe",
    "Use Gravatar and favicon avatars" : "Gebruik Gravatar en favicon avatars",
    "Register as application for mail links" : "Registreer als applicatie voor e-maillinks",
    "Show keyboard shortcuts" : "Toon sneltoetsen",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Laat de app gegevens verzamelen over jouw interacties. Op basis van deze gegevens zal de app zich aanpassen aan je voorkeuren. De gegevens worden alleen lokaal opgeslagen.",
    "Put my text to the bottom of a reply instead of on top of it." : "Zet mijn tekst onderaan een antwoord in plaats van erboven.",
    "Automatically classify importance of new email" : "Automatisch classificeren van belangrijke e-mails",
    "Could not update preference" : "Kon voorkeuren niet bijwerken",
    "From" : "Van",
    "Select account" : "Selecteer account",
    "To" : "Naar",
    "Contact or email address …" : "Contact of e-mailadres ...",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "No contacts found." : "Geen contacten gevonden.",
    "Subject" : "Onderwerp",
    "Subject …" : "Onderwerp ...",
    "This message came from a noreply address so your reply will probably not be read." : "Dit bericht kwam van een noreply-adres. Je antwoord zal dus niet worden gelezen.",
    "The following recipients do not have a PGP key: {recipients}." : "De volgende ontvangers hebben geen PGP key: {recipients}.",
    "Write message …" : "Bericht schrijven ...",
    "Saving draft …" : "Concept aan het opslaan ...",
    "Draft saved" : "Concept opgeslagen",
    "Discard & close draft" : "Verwijderen & concept sluiten",
    "Upload attachment" : "Bijlage uploaden",
    "Add attachment from Files" : "Bijlage toevoegen vanuit Bestanden",
    "Add link" : "Voeg link toe",
    "Enable formatting" : "Inschakelen formattering",
    "Request a read receipt" : "Vraag een leesbevestiging",
    "Encrypt message with Mailvelope" : "Versleutel bericht met Mailvelope",
    "Enter a date" : "Voeg een datum toe",
    "Add share link from {productName} Files" : "Toevoegen deellink van {productName} Bestanden",
    "Send" : "Versturen",
    "Message {id} could not be found" : "Bericht {id} kon niet worden gevonden",
    "Choose a file to add as attachment" : "Kies een bestand om als bijlage toe te voegen",
    "Choose a file to share as a link" : "Kies een bestand om als link te delen",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["De bijlage overschrijdt de toegestane omvang van {size}. Deel de bestanden in plaats daarvan via een link.","De bijlagen overschrijden de toegestane omvang van {size}. Deel de bestanden in plaats daarvan via een link."],
    "No message found yet" : "Nog geen berichten gevonden",
    "Set up an account" : "Maak een account aan",
    "Plain text" : "Platte tekst",
    "Rich text" : "Rijke tekst",
    "No messages in this mailbox" : "Geen berichten in deze inbak",
    "No messages" : "Geen berichten",
    "Draft: " : "Concept:",
    "Unfavorite" : "Favoriet weghalen",
    "Favorite" : "Favoriet",
    "Unread" : "Ongelezen",
    "Read" : "Lezen",
    "Unimportant" : "Onbelangrijk",
    "Mark not spam" : "Markeer als geen-spam",
    "Mark as spam" : "Markeren als spam",
    "Unselect" : "Deselecteren",
    "Select" : "Selecteer",
    "Edit tags" : "Bewerken tags",
    "Move thread" : "Verplaats draadje",
    "Delete thread" : "Verwijder draadje",
    "More actions" : "Meer acties",
    "Edit as new message" : "Bewerk als nieuw bericht",
    "Create event" : "Creëer afspraak",
    "Blind copy recipients only" : "Alleen ontvangers van blinde kopie",
    "No trash mailbox configured" : "Geen verwijderde berichtenmap ingesteld",
    "Could not delete message" : "Kon bericht niet verwijderen",
    "Forward" : "Doorsturen",
    "Load more" : "Laad meer",
    "_Mark {number} unread_::_Mark {number} unread_" : ["Markeer {number} ongelezen","Markeer {number} ongelezen"],
    "_Mark {number} read_::_Mark {number} read_" : ["Markeren {number} als gelezen","Markeren {number} als gelezen"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Markeer {number} als niet belangrijk","Markeer {number} als belangrijk"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Markeer {number} als niet belangrijk","Mark {number} as unimportant"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Favoriet weghalen {number}","Favoriet weghalen {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Favoriet maken {number}","Favoriet maken {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["De-selecteren {number}","De-selecteren {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Verplaatsen {number} draadje","Verplaatsen {number} draadjes"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Doorsturen {number} als bijlage","Doorsturen {number} als bijlage"],
    "_Delete {number} thread_::_Delete {number} threads_" : ["Verwijderen {number} draadje","Verwijderen {number} draadjes"],
    "Report this bug" : "Meld deze fout",
    "All day" : "Alle dagen",
    "Create" : "Aanmaken",
    "Event created" : "Afspraak aangemaakt",
    "Could not create event" : "Kon afspraak niet creëren",
    "Comment" : "Notitie",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "More options" : "Meer opties",
    "Could not open mailbox" : "Kon postbus niet openen",
    "Loading messages …" : "Laden berichten ...",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexeren van je berichten. Dit kan wat tijd kosten voor grote brievenbussen.",
    "Choose target mailbox" : "Kies doel postbus",
    "No more submailboxes in here" : "Niet meer subpostbussen hier",
    "Choose" : "Kies",
    "Important info" : "Belangrijke informatie",
    "Other" : "Ander",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Berichten zullen automatisch als belangrijk gemarkeerd worden, gebaseerd op met welke berichten je gewerkt hebt of welke je als belangrijk hebt gemarkeerd. In het begin moet je misschien handmatig de belangrijkheid aanpassen om het systeem in te leren, maar het wordt beter met de tijd.",
    "The sender of this message has asked to be notified when you read this message." : "De afzender van dit bericht heeft om een leesbevestiging gevraagd.",
    "Notify the sender" : "Informeer de afzender",
    "You sent a read confirmation to the sender of this message." : "Je hebt een leesbevestiging aan de afzender van dit bericht gestuurd.",
    "Could not send mdn" : "Kon mdn niet versturen",
    "Reply" : "Antwoord",
    "Reply to sender only" : "Antwoord alleen op afzender",
    "Move message" : "Verplaats bericht",
    "View source" : "Bekijk bron",
    "Download thread data for debugging" : "Download draadgegevens voor debuggen",
    "Message source" : "Bericht brontekst",
    "Message body" : "Berichttekst",
    "Import into calendar" : "Toevoegen aan agenda",
    "Download attachment" : "Download bijlage",
    "Save to Files" : "Opslaan in Bestanden",
    "Unnamed" : "Onbenoemd",
    "Embedded message" : "Ingebed bericht",
    "Choose a folder to store the attachment in" : "Kies een map op de bijlage in op te slaan",
    "Save all to Files" : "Sla alles op in Bestanden",
    "Download Zip" : "Download Zip",
    "Choose a folder to store the attachments in" : "Selecteer een folder waarin de bijlagen opgeslagen moeten worden",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Dit bericht is versleuteld met PGP. Installeer Mailvelope om het te ontcijferen.",
    "The images have been blocked to protect your privacy." : "De afbeeldingen zijn geblokkeerd om je privacy te beschermen",
    "Show images" : "Tonen afbeeldingen",
    "Show images temporarily" : "Tonen afbeeldingen tijdelijk",
    "Always show images from {sender}" : "Afbeeldingen van {sender} altijd tonen",
    "Always show images from {domain}" : "Afbeeldingen van {domain} altijd tonen",
    "Message frame" : "Berichtenkader",
    "Quoted text" : "Geciteerde tekst",
    "Move" : "Verplaatsen",
    "Moving" : "Verplaatsen",
    "Moving thread" : "Verplaatsen draadje",
    "Moving message" : "Verplaatsen bericht",
    "Quota" : "Quota",
    "Show only subscribed mailboxes" : "Toon alleen geabonneerde postbussen",
    "Add mailbox" : "Toevoegen postbus",
    "Saving" : "Opslaan",
    "Move up" : "Verplaats naar boven",
    "Move down" : "Lager zetten",
    "Remove account" : "Verwijder account",
    "Loading …" : "Aan het laden ...",
    "Not supported by the server" : "Niet ondersteund door de server",
    "{usage} of {limit} used" : "{usage} van {limit} gebruikt",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Het account voor {email} en alle gecachte data zal verwijderd worden van Nextcloud, maar niet van je e-mailprovider.",
    "Remove account {email}" : "Verwijder account {email}",
    "Remove {email}" : "Verwijder {email}",
    "Show all subscribed mailboxes" : "Toon alle geabonneerde postbussen",
    "Show all mailboxes" : "Toon alle postbussen",
    "Collapse mailboxes" : "Postbussen inklappen",
    "Mark all as read" : "Alles als gelezen markeren",
    "Mark all messages of this mailbox as read" : "Markeer alle berichten in deze berichtenbox als gelezen",
    "Add submailbox" : "Toevoegen subpostbus",
    "Edit name" : "Bewerken naam",
    "Clear cache" : "Leegmaken cache",
    "Clear locally cached data, in case there are issues with synchronization." : "Maak de lokale gegevenscache schoon, als er problemen zijn bij synchronisatie.",
    "Subscribed" : "Geabonneerd",
    "Sync in background" : "Synchroniseer op de achtergrond",
    "Delete mailbox" : "Verwijderen postbus",
    "The mailbox and all messages in it will be deleted." : "De postbus en alle berichten erin worden verwijderd.",
    "Delete mailbox {name}" : "Verwijder postbus {name}",
    "An error occurred, unable to rename the mailbox." : "Er is een fout opgetreden, de naam van de mailbox kon niet worden gewijzigd.",
    "_{total} message_::_{total} messages_" : ["{total} bericht","{total} berichten"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ongelezen van de {total}","{unread} ongelezen van de {total}"],
    "Outbox" : "Uitbak",
    "New message" : "Nieuw bericht",
    "Error sending your message" : "Fout bij het versturen van jouw bericht",
    "Go back" : "Ga terug",
    "Retry" : "Opnieuw proberen",
    "Uploading attachments …" : "Bijlage aan het uploaden ...",
    "Sending …" : "Versturen ...",
    "Warning sending your message" : "Waarschuwing bij het versturen van jouw bericht",
    "Send anyway" : "Toch verzenden",
    "Draft" : "Concept",
    "No sent mailbox configured. Please pick one in the account settings." : "Er is geen map voor verzonden berichten ingesteld. Kies er een in de accountinstellingen.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Je probeert een e-mail te versturen met veel ontvangers in Aan en /of Cc. Overweeg om Bcc te gebruiken om de adressen van de ontvangers voor elkaar te verbergen.",
    "No message selected" : "Geen bericht geselecteerd",
    "Message" : "Bericht",
    "Oh Snap!" : "O nee!",
    "Delete" : "Verwijderen",
    "Contacts with this address" : "Contactpersonen met dit adres",
    "Add to Contact" : "Toevoegen aan contactpersoon",
    "New Contact" : "Nieuwe contactpersoon",
    "Copy to clipboard" : "Kopiëren naar het klembord",
    "Contact name …" : "Naam contactpersoon ...",
    "Add" : "Toevoegen",
    "Tags" : "Tags",
    "Select tags" : "Kies tags",
    "Clear" : "Terug",
    "Search" : "Zoeken",
    "Date" : "Datum",
    "Disabled" : "Uitgeschakeld",
    "Enabled" : "Ingeschakeld",
    "Sieve Host" : "Sieve-server",
    "Sieve Security" : "Sieve Security",
    "Sieve Port" : "Sieve poort",
    "Sieve Credentials" : "Sieve inloggegevens",
    "IMAP Credentials" : "IMAP inloggegevens",
    "Custom" : "Maatwerk",
    "Sieve User" : "Sieve gebruiker",
    "Sieve Password" : "Sieve Wachtwoord",
    "Save sieve settings" : "Bewaar sieve instellingen",
    "Save sieve script" : "Bewaar sieve-script",
    "Signature …" : "Handtekening ...",
    "Save signature" : "Handtekening opslaan",
    "Place signature above quoted text" : "Plaats handtekening boven de aangehaalde tekst",
    "Add default tags" : "Voeg standaard tags toe",
    "Rename tag" : "Hernoem tag",
    "Saving new tag name …" : "Sla nieuw tag op ...",
    "Set" : "Stel in",
    "Unset" : "Schakel uit",
    "Add tag" : "Toevoegen tag",
    "Saving tag …" : "Opslaan tag ...",
    "Tag already exists" : "Markering bestaat al",
    "An error occurred, unable to create the tag." : "Er trad een fout op, tag kon niet worden gecreëerd.",
    "An error occurred, unable to rename the tag." : "Er is een fout opgetreden, kan tag niet hernoemen",
    "Not found" : "Niet gevonden",
    "Could not load your message thread" : "Kon je berichtendraad niet laden",
    "Mark as unread" : "Markeren als ongelezen",
    "Mark as read" : "Markeren als gelezen",
    "Delete message" : "Bericht verwijderen",
    "Remove" : "Verwijderen",
    "No senders are trusted at the moment." : "Er zijn nu geen vertrouwder afzenders.",
    "Could not remove trusted sender {sender}" : "Kon vertrouwde afzender niet verwijderen {afzender}",
    "individual" : "individueel",
    "domain" : "domein",
    "(organizer)" : "(organisator)",
    "Untitled event" : "Naamloos evenement",
    "Import into {calendar}" : "Importeer in {calendar}",
    "Event imported into {calendar}" : "Afspraak geïmporteerd in {calendar}",
    "Airplane" : "Vliegtuig",
    "Reservation {id}" : "Reservering {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Vlucht {flightNr} van {depAirport} naar {arrAirport}",
    "Train" : "Trein",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} van {depStation} naar {arrStation}",
    "Train from {depStation} to {arrStation}" : "Trein van {depStation} naar {arrStation}",
    "Mail app" : "Mail toepassing",
    "The mail app allows users to read mails on their IMAP accounts." : "Met de mail-app kunnen gebruikers e-mails lezen op hun IMAP-accounts.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Hier vind je de instellingen voor de instantie. Gebruikersspecifieke instellingen zijn te vinden in de app zelf (linksonder).",
    "Account provisioning" : "Account provisie",
    "A provisioning configuration will provision all accounts with a matching email address." : "Een inrichtingsconfiguratie voorziet alle accounts van een overeenkomstig e-mailadres.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Door het jokerteken (*) in het veld Provisioningdomein te gebruiken, wordt een configuratie gemaakt die van toepassing is op alle gebruikers, op voorwaarde dat ze niet overeenkomen met een andere configuratie.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Het inrichtingsmechanisme geeft prioriteit aan specifieke domeinconfiguraties boven de jokerteken-domeinconfiguratie.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Als er een nieuwe overeenkomende configuratie wordt gevonden nadat de gebruiker al met een andere configuratie was ingericht, heeft de nieuwe configuratie voorrang en wordt de gebruiker opnieuw voorzien van de configuratie.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "Er kan slechts één configuratie per domein zijn en slechts één domeinconfiguratie met jokertekens.",
    "These settings can be used in conjunction with each other." : "Deze instellingen kunnen met elkaar worden gebruikt.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Als je slechts één domein voor alle gebruikers wilt inrichten, gebruik je het jokerteken (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Deze instelling is het meest logisch als je dezelfde back-end gebruiker voor je Nextcloud en mailserver van je organisatie gebruikt.",
    "Provisioning Configurations" : "Provisie Configuratie",
    "Add new config" : "Toevoegen nieuwe configuratie",
    "Provision all accounts" : "Inrichten alle accounts",
    "Anti Spam Service" : "Anti-spam Service",
    "You can set up an anti spam service email address here." : "Je kunt hier een anti-spam service e-mail adres instellen.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Elke e-mail die als spam wordt gemarkeerd wordt naar de anti-spam service verzonden.",
    "Successfully updated config for \"{domain}\"" : "Configuratie voor \"{domain}\" succesvol bijgewerkt",
    "Error saving config" : "Fout bij opslaan config",
    "Saved config for \"{domain}\"" : "Config voor \"{domain}\" opgeslagen",
    "Could not save provisioning setting" : "Kan inrichtingsinstelling niet opslaan",
    "There was an error when provisioning accounts." : "Er trad een fout op bij het inrichten van accounts.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Accounts for \"{domain}\" succesvol verwijderd en ge-deprovisiond ",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Fout bij het verwijderen en uitschrijven van accounts voor '{domain}'",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count} account succevol ingericht.","{count} accounts succevol ingericht."],
    "Anti Spam" : "Anti-spam",
    "Add the email address of your anti spam report service here." : "Voeg het e-mail adres van je anti-spam service rapport hier toe.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Wanneer je deze instelling wordt gebruikt, wordt er een rapport e-mail verzonden naar de SPAM rapporteer server wanneer een gebruiker klikt op \"Markeer als spam\".",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Het originele bericht wordt bijgevoegd als een \"message/rfc822\" bijlage.",
    "\"Mark as Spam\" Email Address" : "\"Markeer als Spam\" E-mail adres",
    "\"Mark Not Junk\" Email Address" : "\"Markeer geen spam\" E-mail Adres",
    "Reset" : "Herstellen",
    "Successfully set up anti spam email addresses" : "Anti-spam e-mail adressen succesvol ingesteld",
    "Error saving anti spam email addresses" : "Fout bij het opslaan van anti-spam e-mail adressen",
    "Successfully deleted anti spam reporting email" : "Anti-spam rapporteer e-mail succesvol toegevoegd",
    "Error deleting anti spam reporting email" : "Fout bij het verwijderen van anti-spam rapporteer email",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "Domain Match: {provisioningDomain}" : "Domein overeenkomst: {provisioningDomain}",
    "Email: {email}" : "E-mail: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} op {host}:{port} ({ssl} versleuteling)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} op {host}:{port} ({ssl} versleuteling)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} op {host}:{port} ({ssl} versleuteling)",
    "Configuration for \"{provisioningDomain}\"" : "Configuratie voor \"{provisioningDomain}\"",
    "General" : "Algemeen",
    "Provisioning domain" : "Provisioningdomein",
    "Email address template" : "E-mailadres sjabloon",
    "IMAP" : "IMAP",
    "User" : "Gebruiker",
    "Host" : "Host",
    "Port" : "Poort",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Inschakelen sieve-integratie",
    "LDAP aliases integration" : "LDAP alias-integratie",
    "Enable LDAP aliases integration" : "Inschakelen LDAP alias-integratie",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "De integratie van LDAP-aliassen leest een kenmerk uit de geconfigureerde LDAP-directory om e-mailaliassen in te richten.",
    "LDAP attribute for aliases" : "LDAP attribuut voor aliassen",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Een attribuut met meerdere waarden om e-mailaliassen in te richten. Voor elke waarde wordt een alias aangemaakt. Aliassen die in Nextcloud bestaan maar niet in de LDAP-directory staan, worden verwijderd.",
    "Save Config" : "Opslaan config",
    "Unprovision & Delete Config" : "De-provision & verwijder config",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% en %EMAIL% zal worden vervangen door de gebruikers UID en e-mail",
    "With the settings above, the app will create account settings in the following way:" : "Met de bovenstaande instellingen maakt de app op de volgende manier accountinstellingen:",
    "E-mail address" : "E-mailadres",
    "Valid until" : "Geldig tot",
    "Certificate" : "Certificaat",
    "Back" : "Terug",
    "Submit" : "Verwerken",
    "Keyboard shortcut" : "Sneltoets",
    "Keyboard shortcuts" : "Sneltoetsen",
    "Speed up your Mail experience with these quick shortcuts." : "Versnel je e-mailervaring met deze handige snelkoppelingen.",
    "Compose new message" : "Opstellen nieuw bericht",
    "Newer message" : "Recenter bericht",
    "Older message" : "Ouder bericht",
    "Toggle star" : "Omschakelen ster",
    "Toggle unread" : "Omschakelen ongelezen",
    "Archive" : "Archiveer",
    "Refresh" : "Verversen",
    "Account connected" : "Account verbonden",
    "Connect your mail account" : "Verbind je e-mailaccount",
    "Itinerary for {type} is not supported yet" : "route voor {type} wordt nog niet ondersteund",
    "All" : "Alle",
    "Drafts" : "Concepten",
    "Favorites" : "Favorieten",
    "Priority inbox" : "Prioriteit",
    "All inboxes" : "Alle postvakken",
    "Inbox" : "Postvak in",
    "Junk" : "Ongewenst",
    "Sent" : "Verzonden",
    "Trash" : "Verwijderen",
    "Error while sharing file" : "Fout bij delen bestand",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nieuw bericht \nvan {from}","%n nieuwe berichten \nvan {from}"],
    "Nextcloud Mail" : "Nextcloud E-mail",
    "Attachments were not copied. Please add them manually." : "Bijlagen zijn niet gekopiëerd. Voeg ze handmatig toe.",
    "Message sent" : "Bericht verstuurd",
    "Could not load {tag}{name}{endtag}" : "Kon niet laden {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Er is een probleem bij het laden {tag}{name}{endtag}",
    "Could not load your message" : "Kon je bericht niet laden",
    "Could not load the desired message" : "Kon het gewenste bericht niet laden",
    "Could not load the message" : "Kon het bericht niet laden",
    "Error loading message" : "Fout bij laden bericht",
    "Forwarding to %s" : "Doorsturen aan %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier als je binnen enkele seconden niet automatisch wordt doorgestuurd.",
    "Redirect" : "Omleiden",
    "The link leads to %s" : "De link verwijst naar %s",
    "Continue to %s" : "Verder naar %s"
},
"nplurals=2; plural=(n != 1);");
